==> org-lsst-ccs-subsystem-power-main-1.2.2-dev-sources.jar: org/lsst/ccs/subsystem/power/RebPsControl.java <==
package org.lsst.ccs.subsystem.power;

import org.lsst.ccs.drivers.rebps.RebPs;
import org.lsst.ccs.monitor.Control;
import org.lsst.ccs.monitor.Device;
import org.lsst.ccs.monitor.Monitor;
import org.lsst.ccs.monitor.MonitorLogUtils;

/**
 ***********************************************
 *
 *  Implements power supply control functions.
 *
 *  @author Owen Saxton
 *
 ***********************************************
 */
public class RebPsControl extends Control {

   /**
    *  Data fields.
    */
    // Derived fields
    private String      shortName;     // Last part of dot-separated name
    private RebPsDevice pDevc;         // Parent (power supply) device


   /**
    *  Constructor.
    *
    *  @param  desc      Description
    *
    *  @param  hwChan    Hardware channel number (REB number)
    */
    public RebPsControl(String desc, int hwChan)
    {
        super();
        super.description = desc;
        super.hwChan = hwChan;
    }


   /**
    *  Configures channel description.
    *
    *  @param  mon   The associated monitor
    *
    *  @param  devc  The parent Device
    */
    @Override
    protected void configure(Monitor mon, Device devc)
    {
        super.configure(mon, devc);
        pDevc = (RebPsDevice)devc;
        try {
            if (!RebPs.testRebNumber(hwChan)) {
                MonitorLogUtils.reportError(log, getName(), "hw channel number", hwChan);
            }
        }
        catch (Exception e) {
        }
        String[] parts = getName().split("\\.");
        shortName = parts[parts.length - 1];
    }


   /**
    *  Writes the power output state to the hardware.
    */
    void writeOutput(boolean value) throws Exception
    {
        //pDevc.writeOutput(value, hwChan);
    }


   /**
    *  Reads the power output state from the hardware.
    */
    boolean readOutput() throws Exception
    {
        return false; //pDevc.readOutput(hwChan);
    }

}

==> org-lsst-ccs-subsystem-power-main-1.3.2-sources.jar: org/lsst/ccs/subsystem/power/RebPsControl.java <==
package org.lsst.ccs.subsystem.power;

import org.lsst.ccs.monitor.Control;
import org.lsst.ccs.monitor.Device;
import org.lsst.ccs.monitor.Monitor;
import org.lsst.ccs.monitor.MonitorLogUtils;

/**
 *  Implements REB power supply control functions.
 *
 *  @author Owen Saxton
 */
public class RebPsControl extends Control {

    /**
     *  Data fields.
     */
    // Derived fields
    private String      shortName;     // Last part of dot-separated name
    private RebPsDevice pDevc;         // Parent (power supply) device


    /**
     *  Constructor.
     *
     *  @param  desc      Description
     *  @param  hwChan    Hardware channel number (REB number)
     */
    public RebPsControl(String desc, int hwChan)
    {
        super();
        super.description = desc;
        super.hwChan = hwChan;
    }


    /**
     *  Configures channel description.
     *
     *  @param  mon   The associated monitor
     *  @param  devc  The parent Device
     */
    @Override
    protected void configure(Monitor mon, Device devc)
    {
        super.configure(mon, devc);
        pDevc = (RebPsDevice)devc;
        try {
            if (!pDevc.getPs().testRebNumber(hwChan)) {
                MonitorLogUtils.reportError(log, getName(), "hw channel number", hwChan);
            }
        }
        catch (Exception e) {
        }
        String[] parts = getName().split("\\.");
        shortName = parts[parts.length - 1];
    }


    /**
     *  Writes the power output state to the hardware.
     */
    void writeOutput(boolean value) throws Exception
    {
        //pDevc.writeOutput(value, hwChan);
    }


    /**
     *  Reads the power output state from the hardware.
     */
    boolean readOutput() throws Exception
    {
        return false; //pDevc.readOutput(hwChan);
    }

}
